summaryrefslogtreecommitdiffstats
path: root/lib/libalpm/trans.h
diff options
context:
space:
mode:
authorAaron Griffin <aaron@archlinux.org>2006-10-20 08:26:55 +0200
committerAaron Griffin <aaron@archlinux.org>2006-10-20 08:26:55 +0200
commit7131b7ac87b9793c06d7b7e59df103658dd76ec7 (patch)
treed20bcf43f1d93118577c50977ce34cc6340460e1 /lib/libalpm/trans.h
parente7f886aac3991b6a12ede9781af741b402dffb64 (diff)
downloadpacman-7131b7ac87b9793c06d7b7e59df103658dd76ec7.tar.gz
pacman-7131b7ac87b9793c06d7b7e59df103658dd76ec7.tar.xz
A handful of minor changes:
* Removed the PMList typedef, in favor of the same naming scheme other structs use 'pmlist_t' * Added a time stamp on debug output, to make it more informational * Moved alpm_db_register to _alpm_db_register, making the public function not take a callback parameter
Diffstat (limited to 'lib/libalpm/trans.h')
-rw-r--r--lib/libalpm/trans.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/libalpm/trans.h b/lib/libalpm/trans.h
index a0b72127..95e672b6 100644
--- a/lib/libalpm/trans.h
+++ b/lib/libalpm/trans.h
@@ -40,9 +40,9 @@ typedef struct __pmtrans_t {
unsigned char type;
unsigned int flags;
unsigned char state;
- PMList *targets; /* PMList of (char *) */
- PMList *packages; /* PMList of (pmpkg_t *) or (pmsyncpkg_t *) */
- PMList *skiplist; /* PMList of (char *) */
+ pmlist_t *targets; /* pmlist_t of (char *) */
+ pmlist_t *packages; /* pmlist_t of (pmpkg_t *) or (pmsyncpkg_t *) */
+ pmlist_t *skiplist; /* pmlist_t of (char *) */
alpm_trans_cb_event cb_event;
alpm_trans_cb_conv cb_conv;
alpm_trans_cb_progress cb_progress;
@@ -79,8 +79,8 @@ void _alpm_trans_free(void *data);
int _alpm_trans_init(pmtrans_t *trans, unsigned char type, unsigned int flags, alpm_trans_cb_event event, alpm_trans_cb_conv conv, alpm_trans_cb_progress progress);
int _alpm_trans_sysupgrade(pmtrans_t *trans);
int _alpm_trans_addtarget(pmtrans_t *trans, char *target);
-int _alpm_trans_prepare(pmtrans_t *trans, PMList **data);
-int _alpm_trans_commit(pmtrans_t *trans, PMList **data);
+int _alpm_trans_prepare(pmtrans_t *trans, pmlist_t **data);
+int _alpm_trans_commit(pmtrans_t *trans, pmlist_t **data);
#endif /* _ALPM_TRANS_H */